package com.aucma.report.mapper;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 通用报表Mapper接口
 *
 * @Author YinQ
 * @create 2023-10-26 10:53
 */
public interface GeneralReportMapper {


    /**
     * 查询清单率报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> inventoryRateReportList(Map hashMap);


    /**
     * 查询生产执行报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> productionExecutionReportList(Map hashMap);

    /**
     * 查询在制品查询报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> WIPInquiryReportList(Map hashMap);

    /**
     * 质量缺陷统计分析
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> qualityDefectsStatisticalAnalysisList(Map hashMap);


    /**
     * 少错件报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> fewerMistakesReportList(Map hashMap);


    /**
     * 质量问题前80报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> qualityIssuesReportList(Map hashMap);

    /**
     * 产品追溯报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> productTraceabilityReportList(Map hashMap);

    /**
     * 扫描下线记录报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> ScanOfflineRecordReportList(Map hashMap);

    /**
     * 测温记录报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> temperatureRecordReportList(Map hashMap);

    /**
     * 灌注记录报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> pourRecordReportList(Map hashMap);
}
